@@ -1,5 +1,4 @@
 from commodutil import forwards
-import cufflinks as cf
 import unittest
 import os
 import pandas as pd
@@ -69,19 +68,6 @@ class TestForwards(unittest.TestCase):
         self.assertAlmostEqual(res[2020].loc[pd.to_datetime('2019-01-02')], -0.25, 2)
         self.assertAlmostEqual(res[2020].loc[pd.to_datetime('2019-05-21')], 0.91, 2)
 
-    def test_curve_zscore(self):
-        df = cf.datagen.lines(1, 5000)
-        hist = df[:'2020']
-        fwd = df.resample('MS').mean()['2020':]
-
-        res = forwards.curve_seasonal_zscore(hist, fwd)
-
-        # indendent calc
-        d = forwards.transforms.monthly_mean(hist).T.describe()
-        z = (d[1].loc['mean'] - fwd.iloc[0][0]) / d[1].loc['std']
-
-        self.assertAlmostEqual(res.iloc[0]['zscore'], z, 2)
-
     def test_fly(self):
         dirname, filename = os.path.split(os.path.abspath(__file__))
         cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
@@ -108,7 +94,7 @@ class TestForwards(unittest.TestCase):
         res = forwards.spread_combinations(contracts)
         self.assertIn('Q1', res)
         self.assertIn('Q1-Q2', res)
-        self.assertIn('1-2', res)
+        self.assertIn('JanFeb', res)
         self.assertIn('Calendar', res)
 
 if __name__ == '__main__':
